@@ -5,7 +5,7 @@ from typing import Sequence, Optional, Any, List
 import pyexlatex as pl
 import pyexlatex.resume as lr
 
-from derobertis_cv.pldata.constants.institutions import UF, VCU
+from derobertis_cv.pldata.constants.institutions import UF_NAME, VCU_NAME
 from derobertis_cv.pldata.courses.main import get_courses
 from derobertis_cv.pldata.employment_model import EmploymentModel
 from derobertis_cv.pltemplates.academic_employment import AcademicEmployment
@@ -60,8 +60,8 @@ def get_professional_jobs(excluded_companies: Optional[Sequence[str]] = None,
 def get_academic_jobs():
 
     courses = get_courses()
-    uf_courses = [course for course in courses if course.university == UF]
-    vcu_courses = [course for course in courses if course.university == VCU]
+    uf_courses = [course for course in courses if course.university == UF_NAME]
+    vcu_courses = [course for course in courses if course.university == VCU_NAME]
 
     return [
         AcademicEmployment(
@@ -69,14 +69,14 @@ def get_academic_jobs():
                 'Conduct research, including project development, data collection and '
                 'cleaning, analysis, and presentation',
             ],
-            UF, 'August 2014 - Present', 'Graduate Assistant', 'Gainesville, FL',
+            UF_NAME, 'August 2014 - Present', 'Graduate Assistant', 'Gainesville, FL',
             courses_taught=[course.to_cv_list() for course in uf_courses]
         ),
         AcademicEmployment(
             [
                 'Conduct research and assist professors in teaching class sections and grading assignments'
             ],
-            VCU, 'September 2013 - August 2014', 'Graduate Assistant', 'Richmond, FL',
+            VCU_NAME, 'September 2013 - August 2014', 'Graduate Assistant', 'Richmond, FL',
             courses_taught=[course.to_cv_list() for course in vcu_courses]
         ),
     ]
\ No newline at end of file
